<?php
/**
 * Transport Movers functions and definitions
 * @package Transport Movers
 */


/* Theme Setup */
if ( ! function_exists( 'transport_movers_setup' ) ) :

function transport_movers_setup() {

	$GLOBALS['content_width'] = apply_filters( 'transport_movers_content_width', 640 );
	
	load_theme_textdomain( 'transport-movers', get_template_directory() . '/languages' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'title-tag' );
	add_theme_support( 'custom-logo', array(
		'height'      => 240,
		'width'       => 240,
		'flex-height' => true,
	) );
	add_image_size('transport-movers-homepage-thumb',240,145,true);
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'transport-movers' ),
	) );
	add_theme_support( 'custom-background', array(
		'default-color' => 'f1f1f1'
	) );

	/*
	 * This theme styles the visual editor to resemble the theme style,
	 * specifically font, colors, icons, and column width.
	 */
	add_editor_style( array( 'css/editor-style.css', transport_movers_font_url() ) );

}
endif; // transport_movers_setup
add_action( 'after_setup_theme', 'transport_movers_setup' );

/*radio button sanitization*/
 function transport_movers_sanitize_choices( $input, $setting ) {
    global $wp_customize; 
    $control = $wp_customize->get_control( $setting->id ); 
    if ( array_key_exists( $input, $control->choices ) ) {
        return $input;
    } else {
        return $setting->default;
    }
}

/* Theme Widgets Setup */
function transport_movers_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Blog Sidebar', 'transport-movers' ),
		'description'   => __( 'Appears on posts and pages', 'transport-movers' ),
		'id'            => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Posts and Pages Sidebar', 'transport-movers' ),
		'description'   => __( 'Appears on posts and pages', 'transport-movers' ),
		'id'            => 'sidebar-2',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Third Column Sidebar', 'transport-movers' ),
		'description'   => __( 'Appears on posts and pages', 'transport-movers' ),
		'id'            => 'sidebar-3',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 1', 'transport-movers' ),
		'description'   => __( 'Appears on posts and pages', 'transport-movers' ),
		'id'            => 'footer-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 2', 'transport-movers' ),
		'description'   => __( 'Appears on posts and pages', 'transport-movers' ),
		'id'            => 'footer-2',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 3', 'transport-movers' ),
		'description'   => __( 'Appears on posts and pages', 'transport-movers' ),
		'id'            => 'footer-3',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 4', 'transport-movers' ),
		'description'   => __( 'Appears on posts and pages', 'transport-movers' ),
		'id'            => 'footer-4',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

}
add_action( 'widgets_init', 'transport_movers_widgets_init' );


/* Theme Font URL */
function transport_movers_font_url(){
	$font_url = '';
	$font_family = array();
	$font_family[] = 'PT Sans:300,400,600,700,800,900';
	$font_family[] = 'Montserrat:300i,400,400i,500,500i,600,600i,700,700i,800,800i,900';
	$font_family[] = 'Ubuntu:500,500i,700';
	$font_family[] = 'Poppins:100i,200,200i,300,300i';

	$query_args = array(
		'family'	=> urlencode(implode('|',$font_family)),
	);
	$font_url = add_query_arg($query_args,'//fonts.googleapis.com/css');
	return $font_url;
}
	
/* Theme enqueue scripts */
function transport_movers_scripts() {
	wp_enqueue_style( 'transport-movers-font', transport_movers_font_url(), array() );
	wp_enqueue_style( 'css-bootstrap', get_template_directory_uri() . '/css/bootstrap.css');
	wp_enqueue_style( 'transport-movers-style', get_stylesheet_uri() );
	wp_style_add_data( 'transport-movers-style', 'rtl', 'replace' );	
	wp_enqueue_style( 'font-awesome', get_template_directory_uri().'/css/fontawesome-all.css' );
	wp_enqueue_script( 'tether-jquery', get_template_directory_uri() . '/js/tether.js', array('jquery') ,'',true);
	wp_enqueue_script( 'bootstrap-jquery', get_template_directory_uri() . '/js/bootstrap.js', array('jquery') ,'',true);	
	wp_enqueue_script( 'transport-movers-custom-scripts-jquery', get_template_directory_uri() . '/js/custom.js', array('jquery') );
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'transport_movers_scripts' );

function transport_movers_ie_stylesheet(){

	wp_enqueue_style('transport-movers-ie', get_template_directory_uri().'/css/ie.css', array('transport-movers-style'));
	wp_style_add_data( 'transport-movers-ie', 'conditional', 'IE' );
}
add_action('wp_enqueue_scripts','transport_movers_ie_stylesheet');

define('TRANSPORT_MOVERS_CREDIT','https://www.buywptemplates.com/','transport-movers');

if ( ! function_exists( 'transport_movers_credit' ) ) {
	function transport_movers_credit(){
		echo "<a href=".esc_url(TRANSPORT_MOVERS_CREDIT)." target='_blank'>".esc_html__('buywptemplates','transport-movers')."</a>";
	}
}

/* Excerpt Limit Begin */
function transport_movers_string_limit_words($string, $word_limit) {
	$words = explode(' ', $string, ($word_limit + 1));
	if(count($words) > $word_limit)
	array_pop($words);
	return implode(' ', $words);
}

//For page ID
function get_page_id_by_title($title){
	$page = get_page_by_title($title);
	return $page->ID;
}

/* Implement the Custom Header feature. */
require get_template_directory() . '/inc/custom-header.php';

/* Custom template tags for this theme. */
require get_template_directory() . '/inc/template-tags.php';

/* Load Jetpack compatibility file. */
require get_template_directory() . '/inc/customizer.php';